<div align="center">
  <a href="https://v2.nonebot.dev/store"><img src="https://github.com/A-kirami/nonebot-plugin-template/blob/resources/nbp_logo.png" width="180" height="180" alt="NoneBotPluginLogo"></a>
  <br>
  <p><img src="https://github.com/A-kirami/nonebot-plugin-template/blob/resources/NoneBotPlugin.svg" width="240" alt="NoneBotPluginText"></p>
</div>

<div align="center">

# nonebot-plugin-person

_✨ Nonebot2 简易插件随个人，随个群友当幸运观众🤪 ✨_


<a href="./LICENSE">
    <img src="https://img.shields.io/github/license/owner/nonebot-plugin-person.svg" alt="license">
</a>
<a href="https://pypi.python.org/pypi/nonebot-plugin-person">
    <img src="https://img.shields.io/pypi/v/nonebot-plugin-person.svg" alt="pypi">
</a>
<img src="https://img.shields.io/badge/python-3.8+-blue.svg" alt="python">

</div>

## 💿 安装

<details>
<summary>使用 nb-cli 安装</summary>
在 nonebot2 项目的根目录下打开命令行, 输入以下指令即可安装

    nb plugin install nonebot-plugin-person

</details>

<details>
<summary>使用包管理器安装</summary>
在 nonebot2 项目的插件目录下, 打开命令行, 根据你使用的包管理器, 输入相应的安装命令

<details>
<summary>pip</summary>

    pip install nonebot-plugin-person
</details>
<details>
<summary>pdm</summary>

    pdm add nonebot-plugin-person
</details>
<details>
<summary>poetry</summary>

    poetry add nonebot-plugin-person
</details>
<details>
<summary>conda</summary>

    conda install nonebot-plugin-person
</details>

打开 nonebot2 项目的 `bot.py` 文件, 在其中写入

    nonebot.load_plugin('nonebot_plugin_person')

</details>

<details>
<summary>从 github 安装</summary>
在 nonebot2 项目的插件目录下, 打开命令行, 输入以下命令克隆此储存库

    git clone https://github.com/owner/nonebot-plugin-person.git

打开 nonebot2 项目的 `bot.py` 文件, 在其中写入

    nonebot.load_plugin('src.plugins.nonebot_plugin_person')

</details>

## 🎉 使用

随个人

随个人帮我打代码

随个人XXX

...

## 📝 TODO LIST

- 支持自定义文案，同时支持是否覆盖原文案
- 输出格式设置

## 📝 更新日志

<details>
<summary>展开/收起</summary>

### 0.0.1

- 插件初次发布

</details>